pub struct RoomCreateEvent<E>(/* private fields */)
where
E: Event;Available on crate feature
state-res only.Expand description
A helper type for an Event of type m.room.create.
This is a type that deserializes each field lazily, when requested.
Implementations
Sourceimpl<E> RoomCreateEvent<E>where
E: Event,
impl<E> RoomCreateEvent<E>where
E: Event,
Sourcepub fn new(event: E) -> RoomCreateEvent<E>
pub fn new(event: E) -> RoomCreateEvent<E>
Construct a new RoomCreateEvent around the given event.
Sourcepub fn room_version(&self) -> Result<RoomVersionId, String>
pub fn room_version(&self) -> Result<RoomVersionId, String>
The version of the room.
Sourcepub fn creators(
&self,
rules: &AuthorizationRules,
) -> Result<HashSet<OwnedUserId>, String>
pub fn creators( &self, rules: &AuthorizationRules, ) -> Result<HashSet<OwnedUserId>, String>
The creators of the room.
If the use_room_create_sender field of AuthorizationRules is set, the creator is the
sender of this m.room.create event, otherwise it is deserialized from the creator
field of this event’s content. Additionally if the explicitly_privilege_room_creators
field of AuthorizationRules is set, any additional user IDs in additional_creators, if
present, will also be considered creators.